*Syntax for generating derived ancestry variables for ESS round 7 data, edition 2.1
*Date: 06/12/2016
*Author: Silke Schneider


************************************BACKGROUND********************************

*The European Social Survey (ESS, see www.europeansocialsurvey.org), a biannual 
*survey of cross-national attitudes and opinions conducted in over 36 European 
*countries since 2001, has developed an approach to collecting data on 
*socio-cultural origins based on a measure of respondents’ self-reported 
*ancestry, i.e. family origins or descent. 
*Included for the first time in ESS Round 7 (2014/15), a questionnaire item 
*was developed which involved countries fielding the item using a 
*country-specific showcard and recoding responses into a newly developed 
*European Standard Classification of Cultural and Ethnic Groups (ESCEG) to 
*create harmonised variables for comparative analysis. When working with such
*detailed classifications, one important question is how to analyse the 
*resulting data, especially if there is a lot of sparsity (i.e. cells with 
*zeros or low case numbers). This syntax proposes a number of ways to 
*combine and aggregate the ancestry variables, which are also used in the below 
*report.  This cannot be exhaustive though because it needs to be guided by 
*specific research questions and theoretical ideas. 

*For further details on the derived ancestry variables and when using data  
*generated using this syntax file, please cite:

*Heath, A.F., Schneider, S.L. and Butt, S. (2016): Developing a measure of 
*socio-cultural origins for the European Social Survey. 
*GESIS Papers: No. 16, 2016. 
*Available at: http://www.gesis.org/unser-angebot/publikationen/gesis-papers/.


*For further details on implementation in individual ESS countries, see: 

*Norwegian Centre for Research Data (2016) Appendix 11 Ancestry ed. 1.0, 
*Available at: 
*http://www.europeansocialsurvey.org/docs/round7/survey/ESS7_appendix_a11_e01_0.pdf.


*For further information on the European Standard Classification of Cultural 
*and Ethnic Groups (ESCEG), see:

*Norwegian Centre for Research Data (2016) Appendix 6: Classifications and 
*coding standards, ESS7-2014 ed. 2.0. Available at: 
*http://www.europeansocialsurvey.org/docs/round7/survey/ESS7_appendix_a6_e02_0.pdf


************************************PREPARATIONS********************************

*Data used: 
*ESS round 7 data, edition 2.1, release date December 1sst, 2016
**http://www.europeansocialsurvey.org/file/download?f=ESS7e02_1.stata.zip&c=&y=2014

*Variables used: 
**anctry1 anctry2 (ancestries reported by respondent, coded in ESCEG)
**cntry (country identifier)

*For the do-file to work on your data and put logs in the desired place, 
*you need to enter the file path in the appropriate places (in the section "PREPARATIONS"). 
*Then simply save and run the do-file.
*If you encounter any problems, please email me: silke.schneider@gesis.org

version 14
capture log close
clear
set more off, perm

*To record results of this syntax in a log file, insert folder for log files:
global log "[ENTER YOUR LOG FOLDER PATH HERE]"
*e.g. global log "D:\Documents\Ancestry work\Data analysis and results"

*please enter path to folder containing your ESS round 7 ed. 2.1 data file:
global data "[ENTER YOUR DATA FOLDER PATH HERE]"
*e.g. global data "D:\Documents\Data&Documentation\ESS7"

cap log close
log using "$log/generatederivedvariables2_1", replace

use "$data\ESS7e02_1.dta", clear
replace cntry=lower(cntry)
numlabel, add

*treat missing on anctry2 as "no second ancestry"
tab anctry2
replace anctry2=555555 if anctry2>555555
tab anctry2


**************************PRODUCING DERIVED VARIABLES***************************
***************************OVERVIEW*********************************************

*1) mentions two ancestries or only one
*2) truncate to 1 digit (broad group)
*3) truncate to 2 digit (narrow group
*4) truncate to 4 digit (national group)
*5) truncate to narrow group for European, broad group for other ancestries
*6) Western ancestry mentioned (separately for 1st and 2nd ancestry)
*7) Western ancestry mentioned, combined over two ancestries
*8) EU (including EFTA) ancestry mentioned (separately for 1st and 2nd ancestry)
*9) EU/EFTA ancestry mentioned, combined over two ancestries
*10) autochthonous (including sub-national) ancestry mentioned (separately for 1st and 2nd ancestry)
*11) autochthonous ancestry mentioned, combined over two ancestries
*12) national (excluding sub-national) ancestry mentioned (separately for 1st and 2nd ancestry)
*13) national ancestry mentioned, combined over two ancestries
*14) sub-national/minority ancestry mentioned (separately for 1st and 2nd ancestry)
*15) sub-national/minority ancestry mentioned, combined over two ancestries
*16) broad groups mentioned vs. only autochthonous
*17) broad groups mentioned vs. autochthonous




******************1) mentions two ancestries or only one************************

*In some countries 1st and 2nd ancestry could be the same, thus code 2nd to ///
*"no 2nd" if this happened
*exclude 'other' category from this operation
*exclude CH and FR from this operation since all CH and FR sub-national /// 
*codes aggregated so we cannot tell whether these are the same or different ones
replace anctry2 = 555555 if anctry1 == anctry2 /// 
	& cntry!="CH" & cntry!="FR" & anctry1 !=444444
*strictly speaking codes ending 8 or 9 should also be excluded from this operation

gen ancn=.
lab var ancn "number of ancestries mentioned"
replace ancn=2 if anctry2<555555 
replace ancn=1 if anctry2>444444 
lab def ancn 1 "one" /// 
	2 "two"
lab val ancn ancn

tab cntry ancn, mis row 



*******************Truncated ancestry variables*********************************
******************2) truncate to 1 digit (broad group)**************************

gen anctry1_1=int(anctry1/10000)
lab var anctry1_1 "broad group first ancestry"

gen anctry2_1=int(anctry2/10000)
lab var anctry2_1 "broad group second ancestry"


******************3) truncate to 2 digit (narrow group)*************************

gen anctry1_2=int(anctry1/1000)
lab var anctry1_2 "narrow group first ancestry"

gen anctry2_2=int(anctry2/1000)
lab var anctry2_2 "narrow group second ancestry"

*because of anonymisation, variable cannot be coded for NO.	
replace anctry1_2 = 66666 if cntry=="no"
replace anctry2_2 = 66666 if cntry=="no"



******************4) truncate to 4 digit (national group)***********************

gen anctry1_4=int(anctry1/10)
lab var anctry1_4 "national group first ancestry"

gen anctry2_4=int(anctry2/10)
lab var anctry2_4 "national group second ancestry"

*because of anonymisation, variable cannot be coded for NO.	
replace anctry1_4 = 66666 if cntry=="no"
replace anctry2_4 = 66666 if cntry=="no"



***5) truncate to narrow group for European, broad group for other ancestries***

gen anctry1_12=.
replace anctry1_12=anctry1_2 if anctry1_1<2
replace anctry1_12=anctry1_1 if anctry1_1>=2
lab var anctry1_12 "broad/narrow group first ancestry"

gen anctry2_12=.
replace anctry2_12=anctry2_2 if anctry2_1<2
replace anctry2_12=anctry2_1 if anctry2_1>=2
lab var anctry2_12 "broad/narrow group second ancestry"

*because of anonymisation, variable cannot be coded for NO.	
replace anctry1_12 = 66666 if cntry=="no"
replace anctry2_12 = 66666 if cntry=="no"



*label truncated ancestry variables (all digits)
lab def anctry 1 "European" ///
2 "MENA and Central Asian" ///
3 "Sub-Saharan African" ///
4 "South and South-East Asian" ///
5 "East Asian" ///
6 "Latin American" ///
7 "Caribbean" ///
8 "North American and Australasian" /// 
44 "other ancestry, not post-coded" /// 
55 "no second ancestry" /// 
77 "refusal" /// 
88 "don't know" /// 
99 "no answer" /// 
10 "European nfs" ///
11 "West European" /// 
12 "North European (Nordic)" /// 
13 "South European" /// 
14 "South-East European" /// 
15 "East European" /// 
20 "MENA and Central Asian nfs" ///
21 "Arab" /// 
22 "Jewish" /// 
23 "Turkish" /// 
24 "Iranian and Central Asian" /// 
25 "Other MENA" /// 
30 "Sub-Saharan African nfs" /// 
31 "West and Central African" /// 
32 "Africa's Horn" /// 
33 "East and South African" /// 
40 "South and SE Asian nfs" /// 
41 "South Asian" /// 
42 "Mainland and Buddhist SE Asian" /// 
43 "Maritime and Muslim SE Asian" /// 
50 "East Asian nfs" /// 
51 "Chinese Asian" /// 
52 "North-East Asian" /// 
60 "Latin American nfs" ///  
61 "South American" /// 
62 "Central American" /// 
70 "Caribbean nfs" /// 
71 "English-speaking Caribbean" /// 
72 "French or Dutch-speaking Caribbean" /// 
80 "North American, Australasian nfs" /// 
81 "North American" /// 
82 "Australasian" /// 
555 "no second ancestry" /// 
444 "other ancestry, not post-coded" /// 
777 "refusal" /// 
888 "don't know" /// 
999 "no answer" /// 
1000 "European nfs" /// 
1100 "West European nfs" /// 
1101 "Austrian" /// 
1102 "Belgian" /// 
1103 "British" /// 
1104 "Dutch" /// 
1105 "French" /// 
1106 "Frisian" /// 
1107 "German" /// 
1108 "Irish" /// 
1109 "Luxembourgish" /// 
1110 "Swiss" /// 
1111 "Yeniche" /// 
1199 "West European nec" /// 
1200 "North European (Nordic) nfs" /// 
1201 "Danish" /// 
1202 "Finnish" /// 
1203 "Icelandic" /// 
1204 "Norwegian" /// 
1205 "Sami" /// 
1206 "Swedish" /// 
1299 "North European nec" /// 
1300 "South European nfs" /// 
1301 "Basque" /// 
1302 "Greek Cypriot" /// 
1303 "Greek" /// 
1304 "Italian" /// 
1305 "Maltese" /// 
1306 "Portuguese" /// 
1307 "Spanish" /// 
1399 "South European nec " /// 
1400 "South-East European nfs" /// 
1401 "Albanian" /// 
1402 "Bosniak" /// 
1403 "Bulgarian" /// 
1404 "Croatian" /// 
1405 "Kosovar" /// 
1406 "Macedonian" /// 
1407 "Moldovan" /// 
1408 "Montenegrin" /// 
1409 "Romanian" /// 
1410 "Roma/Gypsy/Sinti" /// 
1411 "Serbian" /// 
1412 "Slovene" /// 
1413 "Vlach" /// 
1499 "South-East European nec" /// 
1500 "East European nfs" /// 
1501 "Belarusian" /// 
1502 "Czech" /// 
1503 "Estonian" /// 
1504 "Hungarian" /// 
1505 "Latvian" /// 
1506 "Lithuanian" /// 
1508 "Moravian" /// 
1509 "Polish" /// 
1510 "Ruthenian" /// 
1511 "Russian" /// 
1512 "Silesian" /// 
1513 "Slovak" /// 
1514 "Ukrainian" /// 
1515 "Sorbian/Wendish" /// 
1599 "East European nec " /// 
2000 "MENA and Central Asian nfs" /// 
2100 "Arab nfs" /// 
2101 "Algerian" /// 
2102 "Arab Israeli" /// 
2103 "Bahraini" /// 
2104 "Bedouin" /// 
2105 "Egyptian" /// 
2106 "Emirati" /// 
2107 "Iraqi" /// 
2108 "Jordanian" /// 
2109 "Kuwaiti" /// 
2110 "Lebanese" /// 
2111 "Libyan" /// 
2112 "Mauritanian" /// 
2113 "Moroccan" /// 
2114 "Omani" /// 
2115 "Palestinian" /// 
2116 "Qatari" /// 
2117 "Sahrawi/Sahraoui" /// 
2118 "Saudi Arabian" /// 
2119 "Syrian" /// 
2120 "Tunisian" /// 
2121 "Yemeni" /// 
2122 "Muslim" /// 
2199 "Arab nec" /// 
2200 "Jewish nfs" /// 
2201 "Jewish Israeli" /// 
2299 "Jewish nec" /// 
2300 "Turkish" /// 
2400 "Iranian and Central Asian nfs" /// 
2401 "Afghan" /// 
2402 "Azeri" /// 
2403 "Hazara" /// 
2404 "Iranian" /// 
2405 "Kazakh" /// 
2406 "Kyrgyz" /// 
2407 "Pathan" /// 
2408 "Tajik" /// 
2409 "Tatar" /// 
2410 "Turkmen" /// 
2411 "Uighur" /// 
2412 "Uzbek" /// 
2499 "Iranian and Central Asian nec" /// 
2500 "Other MENA nfs" /// 
2501 "Armenian" /// 
2502 "Assyrian/Chaldean" /// 
2503 "Berber" /// 
2504 "Coptic" /// 
2505 "Druze" /// 
2506 "Georgian" /// 
2507 "Israeli" /// 
2508 "Kurdish" /// 
2509 "Mandaean" /// 
2599 "Other MENA nec" /// 
3000 "Sub-Saharan African nfs" /// 
3100 "West and Central African nfs" /// 
3101 "Akan" /// 
3102 "Angolan" /// 
3103 "Beninese" /// 
3104 "Bissau-Guinean" /// 
3105 "Burkinabe" /// 
3106 "Burundian" /// 
3107 "Cabo Verdean" /// 
3108 "Cameroonian" /// 
3109 "Central African" /// 
3110 "Chadian" /// 
3111 "Congolese" /// 
3112 "Ghanaian" /// 
3113 "Guinean" /// 
3114 "Ivorian " /// 
3115 "Liberian" /// 
3116 "Malian" /// 
3117 "Nigerian" /// 
3118 "Rwandan" /// 
3119 "Senegalese" /// 
3120 "Sierra Leonean" /// 
3121 "Yoruban" /// 
3199 "West and Central African nec" /// 
3200 "Africa’s Horn nfs" /// 
3201 "Afar" /// 
3202 "Amhara" /// 
3203 "Djiboutian" /// 
3204 "Eritrean" /// 
3205 "Ethiopian" /// 
3206 "Fur" /// 
3207 "Nubian" /// 
3208 "Oromo" /// 
3209 "Somali" /// 
3210 "Sudanese" /// 
3211 "Tigre" /// 
3212 "Tigray-Tigrinya" /// 
3299 "Africa’s Horn nec" /// 
3300 "East and South African nfs" /// 
3301 "Comoran" /// 
3302 "Dinka" /// 
3303 "Kenyan" /// 
3304 "Malawian" /// 
3305 "Masai" /// 
3306 "Motswana" /// 
3307 "Mozambican" /// 
3308 "Nuer" /// 
3309 "Seychellois" /// 
3310 "South African" /// 
3311 "Tanzanian" /// 
3312 "Ugandan" /// 
3313 "Zambian" /// 
3314 "Zimbabwean" /// 
3315 "Zulu" /// 
3399 "East and South African nec" /// 
4000 "South and SE Asian nfs" /// 
4100 "South Asian nfs" /// 
4101 "Bangladeshi" /// 
4102 "Bhutanese" /// 
4103 "Indian" /// 
4104 "Kashmiri" /// 
4105 "Maldivian" /// 
4106 "Mauritian" /// 
4107 "Nepalese" /// 
4108 "Pakistani" /// 
4109 "Pakistani" /// 
4109 "Parsi" /// 
4110 "Rohingya" /// 
4111 "Sri Lankan" /// 
4112 "Tamil" /// 
4199 "South Asian nec" /// 
4200 "Mainland and Buddhist SE Asian nfs" /// 
4201 "Balinese" /// 
4202 "Burmese" /// 
4203 "Hmong" /// 
4204 "Karen" /// 
4205 "Khmer" /// 
4206 "Lao" /// 
4207 "Mon" /// 
4208 "Thai" /// 
4209 "Vietnamese" /// 
4299 "Mainland and Buddhist SE Asian nec" /// 
4300 "Maritime and Muslim SE Asian nfs" /// 
4301 "Bruneian" /// 
4302 "Indonesian" /// 
4303 "Malay" /// 
4304 "Timorese" /// 
4399 "Maritime and Muslim South-East Asian nec" /// 
5000 "East Asian nfs" /// 
5100 "Chinese Asian nfs" /// 
5101 "Chinese" /// 
5102 "Singaporean" /// 
5103 "Taiwanese" /// 
5199 "Chinese Asian nec" /// 
5200 "North-East Asian nfs" /// 
5201 "Japanese" /// 
5202 "Korean" /// 
5203 "Mongolian" /// 
5204 "Tibetan" /// 
5299 "North-East Asian nec" /// 
6000 "Latin American nfs" /// 
6001 "Amerindian (indigenous SC American nec)" /// 
6100 "South American nfs" /// 
6102 "Argentinian" /// 
6103 "Aymara" /// 
6104 "Bolivian" /// 
6105 "Brazilian" /// 
6106 "Chilean" /// 
6107 "Colombian" /// 
6108 "Ecuadorian" /// 
6109 "Paraguayan" /// 
6110 "Peruvian" /// 
6111 "Quechuan" /// 
6112 "Uruguayan" /// 
6113 "Venezuelan" /// 
6199 "South American nec" /// 
6200 "Central American nfs" /// 
6201 "Costa Rican" /// 
6202 "Cuban" /// 
6203 "Dominican (Dominican Republic)" /// 
6204 "Filipino" /// 
6205 "Guatemalan" /// 
6206 "Honduran" /// 
6207 "Mayan" /// 
6208 "Mexican" /// 
6209 "Nicaraguan" /// 
6210 "Panamanian" /// 
6211 "Puerto Rican" /// 
6212 "Salvadorean" /// 
6299 "Central American nec" /// 
7000 "Caribbean nfs" /// 
7100 "English-speaking Caribbean" /// 
7101 "Anguillan" /// 
7102 "Antiguan" /// 
7103 "Bahamian" /// 
7104 "Barbadian" /// 
7105 "Barbudan" /// 
7106 "Dominican (Dominica)" /// 
7107 "Guyanese" /// 
7108 "Jamaican" /// 
7109 "Trinidadian" /// 
7199 "English-speaking Caribbean nec" /// 
7200 "French or Dutch-speaking Caribbean nfs" /// 
7201 "Antillais" /// 
7202 "Aruban" /// 
7203 "Curacaoan" /// 
7204 "Haitian" /// 
7205 "Surinamese" /// 
7299 "French or Dutch-speaking Caribbean nec" /// 
8000 "North American and Australasian nfs" /// 
8100 "North American nfs" /// 
8101 "American" /// 
8102 "Bermudan" /// 
8103 "Canadian" /// 
8104 "Native North American Indian" /// 
8199 "North American nec" /// 
8200 "Australasian nfs" /// 
8201 "Australian" /// 
8202 "Fijian/iTaukei" /// 
8203 "Maori" /// 
8204 "New Zealander" /// 
8205 "Papua New Guinean" /// 
8206 "Samoan" /// 
8207 "Tahitian" /// 
8208 "Tongan" /// 
8299 "Australasian nec" ///
44444 "other ancestry, not post-coded" /// 
66666 "anonymized" /// 
77777 "refusal" /// 
88888 "don't know" /// 
99999 "no answer"

lab val anctry1_1 anctry2_1 anctry
lab val anctry1_2 anctry2_2 anctry
lab val anctry1_4 anctry2_4 anctry
lab val anctry1_12 anctry2_12 anctry

numlabel, add

tab1 anctry1_1 anctry2_1 anctry1_2 anctry2_2 anctry1_4 anctry2_4, mis  
tab1 anctry1_12 anctry2_12, mis  



**********************6) Western ancestry mentioned*****************************

*respondents reporting western ancestry in each country set to 1
*western=1 "European" or 8 "North American and Australasian"
gen ancwest1=.
replace ancwest1=0 if anctry1<444444
replace ancwest1=1 if anctry1_1==1 |  anctry1_1==8
replace ancwest1=4 if anctry1==444444
replace ancwest1=7 if anctry1==777777
replace ancwest1=8 if anctry1==888888
replace ancwest1=9 if anctry1==999999
lab var ancwest1 "western ancestry mentioned (1st anc)"

gen ancwest2=.
replace ancwest2=0 if anctry2<444444
replace ancwest2=1 if anctry2_1==1 |  anctry2_1==8
replace ancwest2=4 if anctry2==444444
replace ancwest2=5 if anctry2==555555
lab var ancwest2 "western ancestry mentioned (2nd anc)"

lab def ancwest 0 "no" ///
1 "yes" ///
4 "other ancestry, not post-coded" /// 
5 "no 2nd ancestry" /// 
7 "refusal" /// 
8 "don't know" /// 
9 "no answer" 
lab val ancwest1 ancwest2 ancwest

tab1 ancwest1 ancwest2, mis



***********7) Western ancestry mentioned, combined over two ancestries**********

gen ancwestx=.
replace ancwestx=0 if  ancwest1==0 & (ancwest2==0 | ancwest2==5)
replace ancwestx=1 if (ancwest1==0 &  ancwest2==1)|(ancwest1==1 & ancwest2==0)
replace ancwestx=2 if  ancwest1==1 & (ancwest2==1 | ancwest2==5)
replace ancwestx=4 if ancwest1>=4 | ancwest2==4 | ancwest2>=6 
lab var ancwestx "western ancestry mentioned, combined"

lab def ancwestx 0 "no" ///
1 "yes and non-western" /// 
2 "yes only" /// 
4 "one ancestry missing or other" 
lab val ancwestx ancwestx

tab ancwestx, mis



****************8) EU (including EFTA) ancestry mentioned***********************

gen ancEU1=.
replace ancEU1=0 if anctry1<444444
replace ancEU1=4 if anctry1==444444
replace ancEU1=7 if anctry1==777777
replace ancEU1=8 if anctry1==888888
replace ancEU1=9 if anctry1==999999
lab var ancEU1 "EU ancestry mentioned (1st anc)"

gen ancEU2=.
replace ancEU2=0 if anctry2<444444
replace ancEU2=4 if anctry2==444444
replace ancEU2=5 if anctry2==555555
lab var ancEU2 "EU ancestry mentioned (2nd anc)"

*respondents with EU/EFTA ancestry in each country set to 1
reshape long anctry@ anctry@_2 anctry@_4 ancEU@, i(cntry idno)

replace ancEU=1 if /// 
	anctry_2==11 | /// *Western Europe: AT, BE, CH, DE, FR, GB, IE, LU, NL  
	anctry_2==12 | /// *Northern Europe: DK, FI, IS, NO, SE
	anctry_2==13 | /// *Southern Europe: CY, ES, GR, IT, PT, MT
	anctry_4==1403| /// *Bulgarian
	anctry_4==1404| /// *Croatian
	anctry_4==1409| /// *Romanian
	anctry_4==1412| /// *Slovene
	anctry_4==1502| /// *Czech
	anctry_4==1503| /// *Estonian
	anctry_4==1504| /// *Hungarian
	anctry_4==1505| /// *Latvian
	anctry_4==1506| /// *Lithuanian
	anctry_4==1508| /// *Moravian
	anctry_4==1509| /// *Polish
	anctry_4==1513| /// *Slovak
	anctry_4==1512| /// *Silesian
	anctry_4==1515     /*Sorbian/Wendish*/
	
*because of anonymisation, variable cannot be coded for NO.	
replace ancEU =6 if cntry=="no"

reshape wide
	
lab def ancEU 0 "no" ///
1 "yes" ///
4 "other ancestry, not post-coded" /// 
5 "no 2nd ancestry" /// 
6 "anonymized" /// 
7 "refusal" /// 
8 "don't know" /// 
9 "no answer" 
lab val ancEU1 ancEU2 ancEU

tab1 ancEU1 ancEU2, mis

	
	
*********9) EU/EFTA ancestry mentioned, combined over two ancestries******

gen ancEUx=.
replace ancEUx=0 if  ancEU1==0 & (ancEU2==0 | ancEU2==5)
replace ancEUx=1 if (ancEU1==0 &  ancEU2==1)|(ancEU1==1 & ancEU2==0)
replace ancEUx=2 if  ancEU1==1 & (ancEU2==1 | ancEU2==5)
replace ancEUx=4 if ancEU1>=4 | ancEU2==4 | ancEU2>=6
lab var ancEUx "EU/EFTA ancestry mentioned, combined"

lab def ancEUx 0 "no" ///
1 "yes and non-EU/EFTA" /// 
2 "yes only" /// 
4 "one ancestry missing, anonymized or other" 
lab val ancEUx ancEUx

tab ancEUx



***************Derived ancestry variables relative to survey country************

**************10) autochthonous (including sub-national) ancestry mentioned*********

**i.e. respondents likely to have no immigrant ancestry
gen aut1=.
replace aut1=0 if anctry1<777777
replace aut1=7 if anctry1==777777
replace aut1=8 if anctry1==888888
replace aut1=9 if anctry1==999999

gen aut2=.
replace aut2=0 if anctry2<555555

*respondents with autochthonous ancestry in each country set to 1
*ancestries that could be autochthonous or allochthonous will be treated as /// 
*allochthonous if autochthonous poupulation very small 
*(e.g. Germans in BE, Danish in DE, Slovaks in CZ)
reshape long anctry@ anctry@_2 anctry@_4 aut@, i(cntry idno)

replace aut=1 if cntry=="at" & anctry_4==1101  
replace aut=1 if cntry=="be" & anctry_4==1102  
replace aut=1 if cntry=="ch" & (anctry_4==1110|anctry_4==1111)
replace aut=1 if cntry=="cz" & (anctry_4==1502|anctry_4==1508|anctry_4==1512|anctry_4==1513)
replace aut=1 if cntry=="de" & (anctry_4==1107 | anctry_4==1515 |anctry_4==1106 )
replace aut=1 if cntry=="dk" & (anctry_4==1201 )
replace aut=1 if cntry=="ee" & (anctry_4==1503 | anctry==15111|anctry==12023)
replace aut=1 if cntry=="es" & (anctry_4==1307|anctry_4==1399|anctry_4==1301)
replace aut=1 if cntry=="fi" & (anctry_4==1202|anctry_4==1205)
replace aut=1 if cntry=="fr" & (anctry_4==1105|anctry_4==1301|anctry_4==7201)
replace aut=1 if cntry=="gb" & (anctry_4==1103) 
replace aut=1 if cntry=="ie" & (anctry_4==1108) 
replace aut=1 if cntry=="il" & (anctry_4==2507 | anctry_2==	22 |anctry_4== 2100 |anctry_4== 2104 |anctry_4== 2115|anctry_4== 2122|anctry_4== 2505) 
replace aut=1 if cntry=="hu" & (anctry_4==1504|anctry==11077) 
replace aut=1 if cntry=="lt" & (anctry_4==1506) 
replace aut=1 if cntry=="nl" & (anctry_4==1104|anctry_4==1106)
replace aut=1 if cntry=="no" & (anctry_4==1204|anctry_4==1205)
replace aut=1 if cntry=="pl" & (anctry_4==1509|anctry_4==1512) 
replace aut=1 if cntry=="pt" & (anctry_4==1306) 
replace aut=1 if cntry=="se" & (anctry_4==1206|anctry_4==1205)
replace aut=1 if cntry=="si" & (anctry_4==1412) 
replace aut=5 if anctry_4==55555

*Roma and Jewish (outside IL) regarded as autochthonous if no migration background
replace aut=1 if anctry_2==22 & brncntr!=2 & facntr!=2 & mocntr!=2 & cntry!="il"
replace aut=1 if anctry_4==1410 & brncntr!=2 & facntr!=2 & mocntr!=2

*because of anonymisation, variable cannot be coded for NO.
replace aut=6 if cntry=="no"

reshape wide

lab var aut1 "autochthonous ancestry mentioned (1st anc)"
lab var aut2 "autochthonous ancestry mentioned (2nd anc)"

lab def aut 0 "no" ///
1 "yes" ///
5 "no 2nd ancestry" /// 
6 "anonymized" /// 
7 "refusal" /// 
8 "don't know" /// 
9 "no answer" 
lab val aut1 aut2 aut

tab1 aut1 aut2, mis



*********11) autochthonous ancestry mentioned, combined over two ancestries*****

gen autx=.
replace autx=0 if  aut1==0 & (aut2==0 | aut2==5)
replace autx=1 if (aut1==0 &  aut2==1)|(aut1==1 & aut2==0)
replace autx=2 if  aut1==1 & (aut2==1 | aut2==5)
replace autx=4 if aut1>=4 | aut2==4 | aut2>=6
lab var autx "autochtonous ancestry mentioned, combined"

lab def autx 0 "no" ///
1 "yes and allochthonous" /// 
2 "yes only" /// 
4 "one ancestry missing, anonymized or other" 
lab val autx autx
*category 2 includes people claiming two ancestries but both autochthonous /// 
*(such as English and British)

tab autx, mis



********12) national (excluding sub-national) ancestry mentioned****************

gen nat1=.
replace nat1=0 if anctry1<777777
replace nat1=7 if anctry1==777777
replace nat1=8 if anctry1==888888
replace nat1=9 if anctry1==999999

gen nat2=.
replace nat2=0 if anctry2<555555

*respondents mentioning national ancestry nfs in each country set to 1
reshape long anctry@ nat@ anctry@_4, i(cntry idno)

replace nat=1 if cntry=="at" & anctry==11010
replace nat=1 if cntry=="be" & anctry==11020
replace nat=1 if cntry=="ch" & anctry==11100
replace nat=1 if cntry=="cz" & anctry==15020
replace nat=1 if cntry=="de" & anctry==11070
replace nat=1 if cntry=="dk" & anctry==12010
replace nat=1 if cntry=="ee" & anctry==15030
replace nat=1 if cntry=="es" & anctry==13070
replace nat=1 if cntry=="fi" & anctry==12020 
replace nat=1 if cntry=="fr" & anctry==11050
replace nat=1 if cntry=="gb" & anctry==11030
replace nat=1 if cntry=="hu" & anctry==15040
replace nat=1 if cntry=="ie" & anctry==11080
replace nat=1 if cntry=="il" & (anctry==25070 | anctry_4==2200)
/*Jewish considered national ancestry, too*/
replace nat=1 if cntry=="lt" & anctry==15060
replace nat=1 if cntry=="nl" & anctry==11040
replace nat=1 if cntry=="no" & anctry==12040
replace nat=1 if cntry=="pl" & anctry==15090
replace nat=1 if cntry=="pt" & anctry==13060
replace nat=1 if cntry=="se" & anctry==12060
replace nat=1 if cntry=="si" & anctry==14120
replace nat=5 if anctry==555555

*because of anonymisation, variable cannot be coded for NO.
replace nat=6 if cntry=="no"

reshape wide

lab var nat1 "national ancestry mentioned (1st anc)"
lab var nat2 "national ancestry mentioned (2nd anc)"

lab def nat 0 "no" ///
1 "yes" ///
5 "no 2nd ancestry" /// 
6 "anonymized" /// 
7 "refusal" /// 
8 "don't know" /// 
9 "no answer" 
lab val nat1 nat2 nat

tab1 nat1 nat2, mis



**************13) national ancestry mentioned, combined over two ancestries*****

gen natx=.
replace natx=0 if  nat1==0 & (nat2==0| nat2==5)
replace natx=1 if (nat1==0 &  nat2==1)|(nat1==1 & nat2==0)
replace natx=2 if  nat1==1 & (nat2==1| nat2==5)
replace natx=4 if nat1>=4 | nat2==4 | nat2>=6
lab var natx "national ancestry mentioned, combined"

lab def natx 0 "no" ///
1 "yes and other" /// 
2 "yes only" /// 
4 "one ancestry missing, anonymized or other" 
lab val natx natx

tab natx, mis



**************14) sub-national/minority ancestry mentioned**********************

gen sub1=.
replace sub1=0 if anctry1<777777
replace sub1=7 if anctry1==777777
replace sub1=8 if anctry1==888888
replace sub1=9 if anctry1==999999

gen sub2=.
replace sub2=0 if anctry2<555555

*respondents with sub-national or minority ancestry in each country set to 1
*ancestries that could be sub-national/minority or immigrant will be treated as /// 
*immigrant if sub-national/minority poupulation very small 
*(e.g. Germans in BE, Danish in DE, Slovaks in CZ)

reshape long anctry@ anctry@_2 anctry@_4 sub@, i(cntry idno)

replace sub=1 if anctry_4== 1410
replace sub=1 if anctry_2== 22 & cntry!="il"
replace sub=1 if cntry=="at" & (anctry>= 11011 & anctry<= 11019 ) 
replace sub=1 if cntry=="be" & (anctry>= 11021 & anctry<= 11029 ) 
replace sub=1 if cntry=="ch" & (anctry>= 11101 & anctry<= 11109 ) 
replace sub=1 if cntry=="cz" & ((anctry>= 15021 & anctry<= 15029 ) |anctry_4== 1513 |anctry_4== 1508 |anctry_4== 1512 ) 
replace sub=1 if cntry=="de" & ((anctry>= 11071 & anctry<= 11079 ) |anctry_4== 1515 |anctry_4== 1106 ) 
replace sub=1 if cntry=="dk" & (anctry>= 12011 & anctry<= 12019 ) 
replace sub=1 if cntry=="ee" & ((anctry>= 15031 & anctry<= 15039 ) |anctry== 12022 |anctry== 15111 ) 
replace sub=1 if cntry=="es" & ((anctry>= 13071 & anctry<= 13079 ) |anctry_4== 1301 )
replace sub=1 if cntry=="fi" & ((anctry>= 12021 & anctry<= 12029 ) |anctry_4== 1205 )
replace sub=1 if cntry=="fr" & ((anctry>= 11051 & anctry<= 11059 ) |anctry_4== 1301 |anctry_4== 7201 ) 
replace sub=1 if cntry=="gb" & (anctry>= 11031 & anctry<= 11039 ) 
replace sub=1 if cntry=="hu" & ((anctry>= 15041 & anctry<= 15049 ) |anctry_4== 1107 )
replace sub=1 if cntry=="ie" & (anctry>= 11081 & anctry<= 11089 ) 
replace sub=1 if cntry=="il" & ((anctry>= 25071 & anctry<= 25079 ) |anctry_4== 2100 |anctry_4== 2104 |anctry_4== 2115|anctry_4== 2122|anctry_4== 2505 )
replace sub=1 if cntry=="lt" & (anctry>= 15061 & anctry<= 15069 ) 
replace sub=1 if cntry=="nl" & ((anctry>= 11041 & anctry<= 11049 ) |anctry_4== 1106 ) 
replace sub=1 if cntry=="no" & ((anctry>= 12041 & anctry<= 12049 ) |anctry_4== 1205 ) 
replace sub=1 if cntry=="pl" & ((anctry>= 15091 & anctry<= 15099 ) |anctry_4== 1512 ) 
replace sub=1 if cntry=="pt" & (anctry>= 13061 & anctry<= 13069 ) 
replace sub=1 if cntry=="se" & ((anctry>= 12061 & anctry<= 12069 ) |anctry_4== 1205 ) 
replace sub=1 if cntry=="si" & (anctry>= 14121 & anctry<= 14129 ) 
replace sub=5 if anctry==555555

*because of anonymisation, variable cannot be coded for NO.
replace sub=6 if cntry=="no"

reshape wide

lab var sub1 "sub-national/minority ancestry mentioned (1st anc)"
lab var sub2 "sub-national/minority ancestry mentioned (2nd anc)"

lab def sub 0 "no" ///
1 "yes" ///
5 "no 2nd ancestry" /// 
6 "anonymized" /// 
7 "refusal" /// 
8 "don't know" /// 
9 "no answer" 
lab val sub1 sub2 sub

tab1 sub1 sub2, mis



***15) sub-national/minority ancestry mentioned, combined over two ancestries***

gen subx=.
replace subx=0 if  sub1==0 & (sub2==0| sub2==5)
replace subx=1 if (sub1==0 &  sub2==1)|(sub1==1 & sub2==0)
replace subx=2 if  sub1==1 & (sub2==1| sub2==5)
replace subx=4 if sub1>=4 | sub2==4 | sub2>=6
lab var subx "sub-national/minority ancestry mentioned, combined"

lab def subx 0 "no" ///
1 "yes and other" /// 
2 "yes only" /// 
4 "one ancestry missing, anonymized or other" 
lab val subx subx

tab subx, mis



****************16) broad groups mentioned vs. only autochthonous***************
*(priority given to allochthonous membership if dual)
*here the comination of 1st and 2nd ancestry is difficult:
*if somebody mentions two allochthonous ancestries that differ on the 1st digit,
*the first one mentioned is coded. Alternatively, priority could be given
*e.g. to western ancestries.

gen anctryall=anctry1_1
replace anctryall=anctry2_1 if (anctry2_1<44 & anctry1_1>=44)
replace anctryall=0 if autx==2
lab val anctryall anctryall
lab var anctryall "allochthonous ancestry mentioned, in broad groups"
tab1 anctryall 

lab def anctryall 0 "Only autochthonous ancestry" ///
1 "European" ///
2 "MENA and Central Asian" ///
3 "Sub-Saharan African" ///
4 "South and South-East Asian" ///
5 "East Asian" ///
6 "Latin American" ///
7 "Caribbean" ///
8 "North American and Australasian" /// 
44 "other ancestry, not post-coded" /// 
77 "refusal" /// 
88 "don't know" /// 
99 "no answer"

tab anctryall, mis


****************17) broad groups mentioned vs. autochthonous***************
*(priority given to autochthonous membership if dual)
*here the comination of 1st and 2nd ancestry is difficult:
*if somebody mentions two allochthonous ancestries that differ on the 1st digit,
*the first one mentioned is coded. Alternatively, priority could be given
*e.g. to non-western ancestries.

gen anctryaut=anctry1_1
replace anctryaut=anctry2_1 if (anctry2_1<44 & anctry1_1>=44)
replace anctryaut=anctry2_1 if ((anctry2_1==1|anctry2_1==2) & anctry1_1>2 )
replace anctryaut=0 if (autx==2|autx==1)
lab val anctryaut anctry1aut 
lab var anctryaut "autochthonous ancestry mentioned, plus broad groups"

lab def anctry1aut 0 "Autochthonous ancestry mentioned" ///
1 "European" ///
2 "MENA and Central Asian" ///
3 "Sub-Saharan African" ///
4 "South and South-East Asian" ///
5 "East Asian" ///
6 "Latin American" ///
7 "Caribbean" ///
8 "North American and Australasian" /// 
44 "other ancestry, not post-coded" /// 
77 "refusal" /// 
88 "don't know" /// 
99 "no answer"

tab anctryaut, mis


***************************POST-PROCESSING**************************************

numlabel, remove
replace cntry=upper(cntry)

save "$data/ESS7e02_1_ancestrycoded.dta", replace
************************************END*****************************************

log close
exit


